BinaryGroupUsage

Enum BinaryGroupUsage 

#[non_exhaustive]
pub enum BinaryGroupUsage { UnspecifiedUnspecified, UnspecifiedEightBitCodes, ClockTimeUnspecified, Reserved, UnspecifiedDateTimeZone, UnspecifiedPageLine, ClockTimeDateTimeZone, ClockTimePageLine, }
The meaning of the eight binary groups (“user bits”), per the three binary group flag bits BGF2/BGF1/BGF0 (8.3.3, Table 1).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnspecifiedUnspecified

000 — time address reference unspecified, binary group content unspecified (8.4.1).



UnspecifiedEightBitCodes

001 — time address reference unspecified, binary groups hold an eight-bit character set (8.4.2).



ClockTimeUnspecified

010 — time address referenced to clock time, binary group content unspecified (8.4.3, 8.5).



Reserved

011 — reserved for future definition by SMPTE (8.4.4): “shall not be used”.



UnspecifiedDateTimeZone

100 — time address reference unspecified, binary groups hold date and time zone data (8.4.5).



UnspecifiedPageLine

101 — time address reference unspecified, binary groups hold page/line multiplex data (8.4.6).



ClockTimeDateTimeZone

110 — time address referenced to clock time, binary groups hold date and time zone data (8.4.7, 8.5).



ClockTimePageLine

111 — time address referenced to clock time, binary groups hold page/line multiplex data (8.4.8, 8.5).

Implementations

Source

impl BinaryGroupUsage

pub fn name(&self) -> &'static str

The spec’s own compound label (Table 1’s “Time address reference” / “Binary group” column pair).

pub fn from_flags(bgf2: bool, bgf1: bool, bgf0: bool) -> Self

Look up the Table 1 row for a given BGF2/BGF1/BGF0 combination.